@@ -21,7 +21,7 @@ import os
 
 import gi
 from safeeyes import utility
-from safeeyes.model import Config
+from safeeyes.model import Config, PluginDependency
 
 gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
@@ -170,14 +170,16 @@ class SettingsDialog:
                 self.__initialize(self.config)
             widget.destroy()
 
-        messagedialog = Gtk.MessageDialog(parent=self.window,
-                                          flags=Gtk.DialogFlags.MODAL,
-                                          type=Gtk.MessageType.WARNING,
-                                          buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                                                   _("Reset"), Gtk.ResponseType.OK),
-                                          message_format=_("Are you sure you want to reset all settings to default?"))
+        messagedialog = Gtk.MessageDialog()
+        messagedialog.set_modal(True)
+        messagedialog.set_transient_for(self.window)
+        messagedialog.set_property('message_type', Gtk.MessageType.WARNING)
+        messagedialog.set_property('text', _("Are you sure you want to reset all settings to default?"))
+        messagedialog.set_property('secondary-text', _("You can't undo this action."))
+        messagedialog.add_button('_Cancel', Gtk.ResponseType.CANCEL)
+        messagedialog.add_button(_("Reset"), Gtk.ResponseType.OK)
+
         messagedialog.connect("response", __confirmation_dialog_response)
-        messagedialog.format_secondary_text(_("You can't undo this action."))
         messagedialog.show()
 
     def __delete_break(self, break_config, is_short, on_remove):
@@ -194,14 +196,16 @@ class SettingsDialog:
                 on_remove()
             widget.destroy()
 
-        messagedialog = Gtk.MessageDialog(parent=self.window,
-                                          flags=Gtk.DialogFlags.MODAL,
-                                          type=Gtk.MessageType.WARNING,
-                                          buttons=(Gtk.STOCK_CANCEL, Gtk.ResponseType.CANCEL,
-                                                   _("Delete"), Gtk.ResponseType.OK),
-                                          message_format=_("Are you sure you want to delete this break?"))
+        messagedialog = Gtk.MessageDialog()
+        messagedialog.set_modal(True)
+        messagedialog.set_transient_for(self.window)
+        messagedialog.set_property('message_type', Gtk.MessageType.WARNING)
+        messagedialog.set_property('text', _("Are you sure you want to delete this break?"))
+        messagedialog.set_property('secondary-text', _("You can't undo this action."))
+        messagedialog.add_button('_Cancel', Gtk.ResponseType.CANCEL)
+        messagedialog.add_button(_("Delete"), Gtk.ResponseType.OK)
+
         messagedialog.connect("response", __confirmation_dialog_response)
-        messagedialog.format_secondary_text(_("You can't undo this action."))
         messagedialog.show()
 
     def __create_plugin_item(self, plugin_config):
@@ -216,22 +220,36 @@ class SettingsDialog:
         lbl_plugin_name.set_label(_(plugin_config['meta']['name']))
         switch_enable.set_active(plugin_config['enabled'])
         if plugin_config['error']:
-            lbl_plugin_description.set_label(_(plugin_config['meta']['description']))
+            message = plugin_config['meta']['dependency_description']
+            if isinstance(message, PluginDependency):
+                lbl_plugin_description.set_label(_(message.message))
+                btn_plugin_extra_link = builder.get_object('btn_plugin_extra_link')
+                btn_plugin_extra_link.set_label(_("Click here for more information"))
+                btn_plugin_extra_link.set_uri(message.link)
+                btn_plugin_extra_link.set_visible(True)
+            else:
+                lbl_plugin_description.set_label(_(message))
             lbl_plugin_name.set_sensitive(False)
             lbl_plugin_description.set_sensitive(False)
             switch_enable.set_sensitive(False)
+            btn_properties.set_sensitive(False)
+            if plugin_config['enabled']:
+                btn_disable_errored = builder.get_object('btn_disable_errored')
+                btn_disable_errored.set_visible(True)
+                btn_disable_errored.connect('clicked', lambda button: self.__disable_errored_plugin(button, plugin_config))
+
         else:
             lbl_plugin_description.set_label(_(plugin_config['meta']['description']))
+            if plugin_config['settings']:
+                btn_properties.set_sensitive(True)
+                btn_properties.connect('clicked', lambda button: self.__show_plugins_properties_dialog(plugin_config))
+            else:
+                btn_properties.set_sensitive(False)
         self.plugin_switches[plugin_config['id']] = switch_enable
         if plugin_config.get('break_override_allowed', False):
             self.plugin_map[plugin_config['id']] = plugin_config['meta']['name']
         if plugin_config['icon']:
             builder.get_object('img_plugin_icon').set_from_file(plugin_config['icon'])
-        if plugin_config['settings']:
-            btn_properties.set_sensitive(True)
-            btn_properties.connect('clicked', lambda button: self.__show_plugins_properties_dialog(plugin_config))
-        else:
-            btn_properties.set_sensitive(False)
         box = builder.get_object('box')
         box.set_visible(True)
         return box
@@ -243,6 +261,13 @@ class SettingsDialog:
         dialog = PluginSettingsDialog(plugin_config)
         dialog.show()
 
+    def __disable_errored_plugin(self, button, plugin_config):
+        """
+        Permanently disable errored plugin
+        """
+        button.set_sensitive(False)
+        self.plugin_switches[plugin_config['id']].set_active(False)
+
     def __show_break_properties_dialog(self, break_config, is_short, parent, on_close, on_add, on_remove):
         """
         Show the BreakProperties dialog
@@ -254,7 +279,7 @@ class SettingsDialog:
         """
         Show the SettingsDialog.
         """
-        self.window.show_all()
+        self.window.show()
 
     def on_switch_postpone_activate(self, switch, state):
         """
