@@ -32,7 +32,6 @@ import sys
 import shutil
 import subprocess
 import threading
-from distutils.version import LooseVersion
 from logging.handlers import RotatingFileHandler
 from pathlib import Path
 
@@ -43,6 +42,7 @@ gi.require_version('Gtk', '3.0')
 from gi.repository import Gtk
 from gi.repository import GLib
 from gi.repository import GdkPixbuf
+from packaging.version import parse
 
 gi.require_version('Gdk', '3.0')
 
@@ -241,9 +241,8 @@ def load_plugins_config(safeeyes_config):
             continue
         dependency_description = check_plugin_dependencies(plugin['id'], config, plugin.get('settings', {}), plugin_path)
         if dependency_description:
-            plugin['enabled'] = False
             config['error'] = True
-            config['meta']['description'] = dependency_description
+            config['meta']['dependency_description'] = dependency_description
             icon = get_resource_path('ic_warning.png')
         else:
             config['error'] = False
@@ -274,7 +273,7 @@ def desktop_environment():
             env = 'lxde'
         elif 'plasma' in desktop_session or desktop_session.startswith('kubuntu') or os.environ.get('KDE_FULL_SESSION') == 'true':
             env = 'kde'
-        elif os.environ.get('GNOME_DESKTOP_SESSION_ID'):
+        elif os.environ.get('GNOME_DESKTOP_SESSION_ID') or desktop_session.startswith('gnome'):
             env = 'gnome'
         elif desktop_session.startswith('ubuntu'):
             env = 'unity'
@@ -366,21 +365,28 @@ def initialize_safeeyes():
     # Remove the ~/.config/safeeyes/safeeyes.json file
     delete(CONFIG_FILE_PATH)
 
-    # Create the XDG_CONFIG_HOME(or ~/.config)/safeeyes/style directory
-    mkdir(STYLE_SHEET_DIRECTORY)
+    if not os.path.isdir(CONFIG_DIRECTORY):
+        mkdir(CONFIG_DIRECTORY)
 
     # Copy the safeeyes.json
     shutil.copy2(SYSTEM_CONFIG_FILE_PATH, CONFIG_FILE_PATH)
     os.chmod(CONFIG_FILE_PATH, 0o777)
 
+    create_user_stylesheet_if_missing()
+
+    # initialize_safeeyes gets called when the configuration file is not present, which happens just after installation or manual deletion of .config/safeeyes/safeeyes.json file. In these cases, we want to force the creation of a startup entry
+    create_startup_entry(force=True)
+
+def create_user_stylesheet_if_missing():
+    # Create the XDG_CONFIG_HOME(or ~/.config)/safeeyes/style directory
+    if not os.path.isdir(STYLE_SHEET_DIRECTORY):
+        mkdir(STYLE_SHEET_DIRECTORY)
+
     # Copy the new style sheet
     if not os.path.isfile(STYLE_SHEET_PATH):
         shutil.copy2(SYSTEM_STYLE_SHEET_PATH, STYLE_SHEET_PATH)
         os.chmod(STYLE_SHEET_PATH, 0o777)
 
-    # initialize_safeeyes gets called when the configuration file is not present, which happens just after installation or manual deletion of .config/safeeyes/safeeyes.json file. In these cases, we want to force the creation of a startup entry
-    create_startup_entry(force=True)
-
 def create_startup_entry(force=False):
     """
     Create start up entry.
@@ -547,7 +553,7 @@ def __update_plugin_config(plugin, plugin_config, config):
     if plugin_config is None:
         config['plugins'].remove(plugin)
     else:
-        if LooseVersion(plugin.get('version', '0.0.0')) != LooseVersion(plugin_config['meta']['version']):
+        if parse(plugin.get('version', '0.0.0')) != parse(plugin_config['meta']['version']):
             # Update the configuration
             plugin['version'] = plugin_config['meta']['version']
             setting_ids = []
